package com.community.commom.fushi;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.fushi.error.FuShiException;
import com.google.common.collect.Maps;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

import java.util.Map;
import java.util.TreeMap;

/**
 * 富士请求 API
 * @author weiximei
 */
@Data
@Slf4j
public class FuShiRequestAPI {

    private FuShiHttpClient client;

    public FuShiRequestAPI(FuShiHttpClient client) {
        this.client = client;
    }

    public FuShiRequestAPI() {
    }

    // =======================   请求 API   =====================================

    @Data
    @AllArgsConstructor
    public class SignBuild {
        private String sign;
        private String timestamp;
    }

    /**
     * 请求签名
     * @param jsonString
     * @return
     */
    private SignBuild requestSign(String jsonString) {
        String sign = "";
        String timestamp = client.getTimestamp();
        TreeMap<String, String> map = new TreeMap();
		map.put("param", jsonString);
		map.put("secret", client.getAppSecret());
		map.put("timestamp", timestamp);
		sign = client.signWithoutMD5(map);
		sign = client.sign(sign, client.getPrivateKey());

		return new SignBuild(sign, timestamp);
    }

    /**
     * 校验code
     * @param jsonString
     */
    private void showException(String jsonString) {
        JSONObject jsonObject = JSONObject.parseObject(jsonString);
        Integer messageCode = jsonObject.getInteger("MessageCode");
        if (messageCode != 200) {
            throw new FuShiException("设备还未联网，系统维护中");
        }

    }

    /**
     * 获取停车信息（通过车牌号）
     * @return
     */
    public String getParkInfoByCarNo(String parkingCode, String carNo) {
        Map<String, Object> map = Maps.newHashMap();
        map.put("ParkingCode", parkingCode);
        map.put("CarNo", carNo);
        String json = JSONObject.toJSONString(map);
        log.info("获取停车信息（通过车牌号）请求参数：{}", json);
        SignBuild signBuild = requestSign(json);
        String result = client.doJsonPost(FushiConstant.PARK_GETPARKINFOBYCARNO, json, signBuild.getSign(), signBuild.getTimestamp());
        showException(result);
        log.info("获取停车信息（通过车牌号）返回数据：{}", result);
        return result;
    }


    /**
     * 第三方月卡上发续费
     * @param renewDayType 续费日期类型: 3:年; 2:月; 1:日;
     * @param renewDay 续费日期数目
     * @param dealNo 交易编码
     * @param payStyle 交易方式（汉字描述），例如：微信、支付宝、银联
     * @param carNo 车牌号
     * @param cardNo 停车卡号
     * @param parkingCode 停车场编码
     * @param rechargeAmt 充值续费金额
     * @param thirdTransactionDate 第三方交易日期
     * @return
     */
    public String apiThirdPartyMonthCardPay(String renewDayType, String renewDay, String dealNo, String payStyle, String carNo, String parkingCode, String cardNo, String rechargeAmt, String thirdTransactionDate) {
        Map<String, Object> map = Maps.newHashMap();
        map.put("RenewDayType", parkingCode);
        map.put("RenewDay", renewDay);
        map.put("DealNo", dealNo);
        map.put("PayStyle", payStyle);
        map.put("CarNo", carNo);
        map.put("ParkingCode", parkingCode);
        map.put("CardNo", cardNo);
        map.put("RechargeAmt", rechargeAmt);
        map.put("ThirdTransactionDate", thirdTransactionDate);

        String json = JSONObject.toJSONString(map);
        log.info("第三方月卡上发续费请求参数：{}", json);
        SignBuild signBuild = requestSign(json);
        String result = client.doJsonPost(FushiConstant.CALCULATIONCOST_APITHIRDPARTYMONTHCARDPAY, json, signBuild.getSign(), signBuild.getTimestamp());
        showException(result);
        log.info("第三方月卡上发续费返回数据：{}", result);
        return result;
    }







}
