package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.community.commom.ailiyun.AESDecode;
import com.community.commom.constant.Constant;
import com.community.commom.hk.HKOpenApi;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.common.welcome.WelcomeProperties;
import com.community.huiju.dao.TaFaceMapper;
import com.community.huiju.dao.TaSysRoleMapper;
import com.community.huiju.dao.TaUserMapper;
import com.community.huiju.dao.TaUserVerifyMapper;
import com.community.huiju.exception.WisdomException;
import com.community.huiju.model.TaFace;
import com.community.huiju.model.TaUser;
import com.community.huiju.model.TaUserVerify;
import com.community.huiju.service.FaceServiceI;
import com.community.huiju.service.ImageServiceI;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service("faceServicel")
@Transactional
@Slf4j
public class FaceServicelimpl implements FaceServiceI {


    @Autowired
    private TaFaceMapper taFaceMapper;

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TaSysRoleMapper taSysRoleMapper;

    @Autowired
    private ImageServiceI imageServiceI;

    @Autowired
    private WelcomeProperties welcomeProperties;

    @Autowired
    private TaUserVerifyMapper taUserVerifyMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean addFace(UserElement userElement, MultipartFile uploadFile, Integer otherUserId,String phaseName,String buildingName,String unitName,String levelName,String roomNoName) {
        ResponseBean responseBean = new ResponseBean();
        // 当前人脸图片url
        String faceImg = img(uploadFile);
        //查看当前期/栋/单元/楼层/户是否存在
        TaUserVerify taUserVerify= infoExist(phaseName,buildingName,unitName,levelName, roomNoName,otherUserId);
        if (null==taUserVerify){
            responseBean.addError("请查看期/栋/单元/楼层/户号是否正确");
            return responseBean;
        }
        // 是否审核通过
        if (null!=taUserVerify && !taUserVerify.getVerifyStatus().equals("1")){
            responseBean.addSuccess("当前房产未通过审核");
            return responseBean;
        }
        TaFace taFace = new TaFace();
        taFace.setFaceImg(faceImg);
        taFace.setCommunityId(taUserVerify.getCommunityId());
        taFace.setTaUserVerifyId(taUserVerify.getId());
        taFace.setCreateUser(userElement.getId());
        taFace.setCreateDate(LocalDateTime.now());
        /*推送海康 */
        boolean isA =true;
         responseBean = checKout(faceImg, taFace, isA, uploadFile, otherUserId);
        return responseBean;
    }

    /**
     * 修改人脸信息
     *
     * @param userElement 登入人ID
     * @param uploadFile
     * @param otherUserId 关联家属或者租客ID
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean upDateFace(UserElement userElement, MultipartFile uploadFile, Integer otherUserId,String phaseName,String buildingName,String unitName,String levelName,String roomNoName) {
        ResponseBean responseBean = new ResponseBean();
        // 人脸图片地址url
        String faceImg = img(uploadFile);

        //查看当前期/栋/单元/楼层/户是否存在
        TaUserVerify taUserVerify= infoExist(phaseName,buildingName,unitName,levelName, roomNoName,otherUserId);
        if (null==taUserVerify){
            responseBean.addError("请查看期/栋/单元/楼层/户号是否正确");
            return responseBean;
        }

        TaFace face = taFaceMapper.getByUserVerifyId(taUserVerify.getId());
        if (null==face){
            responseBean.addError("当前信息暂无人脸，请录入");
            return responseBean;
        }
        face.setTaUserVerifyId(taUserVerify.getId());
        face.setFaceImg(faceImg);
        face.setUpdateUser(userElement.getId());
        face.setUpdateDate(LocalDateTime.now());
        boolean isA=false;
        ResponseBean resps = checKout(faceImg, face, isA, uploadFile, otherUserId);
        return resps;
    }

    /**
     * 验证图片是否为人脸，推送海康
     */
    public ResponseBean checKout(String faceImg, TaFace taFace, boolean isA, MultipartFile uploadFile, Integer userId) {
        ResponseBean responseBean = new ResponseBean();
        TaUser user = taUserMapper.selectById(userId);
        if (user.getHkUserId() == null) {
            responseBean.addError("海康人员ID不存在，无法录入");
            log.error("本地库人员ID：{}  的海康人员ID不存在", userId);
            return responseBean;
        }
        AESDecode aesd = new AESDecode();
        String body = "{\"type\": \"0\", \"image_url\":\"" + faceImg + "\"}";
        try {
            responseBean = aesd.send(body);
            JSONObject jsonObject = JSONObject.parseObject(responseBean.getMessage());
            Integer type = (Integer) jsonObject.get("errno");
            Integer faceNum = (Integer) jsonObject.get("face_num");

            /*推送海康*/
            String data = HKOpenApi.HKpersonGroupId(uploadFile, user.getHkUserId(), user.getHkPersonNo(), user.getUserName(), user.getHkCardNo());
            /*boolean isA为true进行添加，为false进行修改*/
            if (0 == type && 1 == faceNum) {
                if (null == data) {
                    throw new RuntimeException("海康人脸推送失敗！");
                }
                if (isA) {
                    taFaceMapper.insertSelective(taFace);
                } else {
                    taFaceMapper.updateByPrimaryKeySelective(taFace);
                }
                responseBean.addSuccess("操作成功");
                HKOpenApi.downloadFaceAndFingerInfos(String.valueOf(user.getHkUserId()));
//                //可视对讲时 指定人员人脸权限下载
//                List<Integer> userIdList = new ArrayList<>();
//                userIdList.add(user.getHkUserId());
//                //临时设备编号
//                // TODO 根据期楼栋号，来查询出门口机
//                List<String> visualList = new ArrayList<>();
//                visualList.add("10010100000");
//                HKOpenApi.visualIntercom(null, 1, userIdList, visualList);
            } else {
                responseBean.addError("请录入正确图片");
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("海康人脸推送失敗！ {}", e);
            throw new RuntimeException("海康人脸推送失敗！");
        }
        return responseBean;
    }

    /**
     * 当前登入人是否有人脸信息
     */
    @Override
    public ResponseBean getTaFaceByUserId(UserElement userElement, Integer otherUserId,String phaseName,String buildingName,String unitName,String levelName,String roomNoName) {
        ResponseBean responseBean = new ResponseBean();
        //查看当前期/栋/单元/楼层/户是否存在
        TaUserVerify taUserVerify= infoExist(phaseName,buildingName,unitName,levelName, roomNoName,otherUserId);
        if (null==taUserVerify){
            responseBean.addError("请查看期/栋/单元/楼层/户号是否正确");
            return responseBean;
        }

        TaFace face = taFaceMapper.getByUserVerifyId(taUserVerify.getId());
        if (null==face){
            responseBean.addError("当前用户暂无人脸图片");
            return responseBean;
        }
        responseBean.addSuccess(face);
        return responseBean;

    }

    @Override
    public ResponseBean deleteFace(Integer otherUserId, String phaseName, String buildingName, String unitName, String levelName, String roomNoName) {
        TaUserVerify taUserVerify= infoExist(phaseName,buildingName,unitName,levelName, roomNoName,otherUserId);
        TaUser taUser= taUserMapper.selectById(taUserVerify.getUserId());
        // TODO 删除人脸，是否删除海康
//        HKOpenApi.selectUser(taUser.getHkUserId());
        HKOpenApi.deleteUser(taUser.getHkUserId());
        return null;
    }

    /**
     * 得到当前图片
     */
    private String img(MultipartFile uploadFile) {
        String faceImg = null;
        try {
            faceImg = imageServiceI.getImageUrl(uploadFile);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return faceImg;
    }

    /*查询当前期/栋/单元/房间号结果是否存在*/
    public TaUserVerify infoExist(String phaseName,String buildingName,String unitName,String levelName,String roomNoName,Integer otherUserId){
        if (null==phaseName){
            return null;
        }else if (null==buildingName){
            return null;
        }else if (null==unitName){
            return null;
        }else if (null==levelName){
            return null;
        }else if (null==roomNoName){
            return null;
        }
        /*查询当前的房产ID*/
        QueryWrapper<TaUserVerify>  queryTaUserVerify= new QueryWrapper<>();
        queryTaUserVerify.eq("phase_name",phaseName);
        queryTaUserVerify.eq("building_name",buildingName);
        queryTaUserVerify.eq("unit_name",unitName);
        queryTaUserVerify.eq("level_name",levelName);
        queryTaUserVerify.eq("room_no_name",roomNoName);
        queryTaUserVerify.eq("user_id",otherUserId);
        TaUserVerify taUserVerify= taUserVerifyMapper.selectOne(queryTaUserVerify);
        return taUserVerify;
    }
}


