package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.fushi.FuShiRequestAPI;
import com.community.commom.mode.ResponseBean;
import com.community.commom.uuid.IdGen;
import com.community.huiju.common.perproties.FuShiProperties;
import com.community.huiju.service.IFuShiService;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Map;

/**
 * 富士业务实现
 * @author weiximei
 */
@Slf4j
@Service
public class FuShiServiceImpl implements IFuShiService {

    @Autowired
    private FuShiRequestAPI fuShiRequestAPI;

    @Autowired
    private FuShiProperties fuShiProperties;

    private IdGen idGen = IdGen.get();

    /**
     * 获取 富士 json 值
     * @param jsonString
     * @return
     */
    private Map<String,Object> getFuShiInfo(String jsonString) {
        JSONObject jsonObject = JSONObject.parseObject(jsonString);
        Map<String, Object> map = Maps.newHashMap();
        map.put("JsonParam", jsonObject.getJSONObject("JsonParam").getInnerMap());
        map.put("Redirect", jsonObject.getString("Redirect"));
        map.put("DataType", jsonObject.getInteger("DataType"));
        return map;
    }

    @Override
    public ResponseBean getParkInfoByCarNo(String carNo) {
        ResponseBean responseBean = new ResponseBean();
        String parkInfo = fuShiRequestAPI.getParkInfoByCarNo(fuShiProperties.getParkingCode(), carNo);
        Map<String, Object> fuShiInfo = getFuShiInfo(parkInfo);
        responseBean.addSuccess(fuShiInfo);
        return responseBean;
    }

    @Override
    public ResponseBean apiThirdPartyMonthCardPay(String renewDayType, String renewDay, String payStyle, String carNo, String cardNo,String rechargeAmt) {
        ResponseBean responseBean = new ResponseBean();
        DateTimeFormatter dateTimeFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd hh:mm:ss");
        // 交易编码
        String dealNo = idGen.nextId() + "";
        // 第三方交易日期
        String dateTime = dateTimeFormatter.format(LocalDateTime.now());
        // 富士云请求
        String partyMonthCardPay = fuShiRequestAPI.apiThirdPartyMonthCardPay(renewDayType, renewDay, dealNo, payStyle, carNo, fuShiProperties.getParkingCode(), cardNo, rechargeAmt, dateTime);
        String tradeNo = JSONObject.parseObject(partyMonthCardPay).getString("TradeNo");
        Map<String, Object> map = Maps.newHashMap();
        map.put("TradeNo", tradeNo);
        responseBean.addSuccess(map);
        return responseBean;
    }
}
